@@ -1,12 +1,16 @@
 context("testing cr_members")
 
-a <- cr_members(member_ids=98)
-b <- cr_members(member_ids=98, works=TRUE)
-c <- cr_members(member_ids=c(10,98,45,1,9))
-d <- cr_members(member_ids=c(10,98,45,1,9), works=TRUE)
-e <- cr_members(query='ecology')
 
-test_that("cr_members returns correct class", {
+test_that("cr_members returns", {
+  skip_on_cran()
+  
+  a <- cr_members(member_ids=98)
+  b <- cr_members(member_ids=98, works=TRUE)
+  c <- cr_members(member_ids=c(10,98,45,1,9))
+  d <- cr_members(member_ids=c(10,98,45,1,9), works=TRUE)
+  e <- cr_members(query='ecology')
+  
+  # correct class
   expect_is(a, "list")
   expect_null(a$meta)
   expect_is(a$data, "data.frame")
@@ -22,9 +26,8 @@ test_that("cr_members returns correct class", {
   expect_is(d, "list")
   expect_is(e, "list")
   expect_equal(e$facets, NULL)
-})
 
-test_that("cr_members dimensions are correct", {
+  # dimensions are correct
   expect_equal(length(a), 3)
   expect_equal(length(b), 3)
   expect_equal(length(e), 3)
@@ -32,6 +35,8 @@ test_that("cr_members dimensions are correct", {
 })
 
 test_that("cr_members fails correctly", {
+  skip_on_cran()
+  
   library('httr')
   expect_error(cr_members(config=timeout(0.01)))
   expect_equal(NROW(cr_members(query = "adfaaf")$data), 0)
