@@ -1,16 +1,20 @@
 context("testing cr_works")
 
-a <- cr_works(query="NSF")
-b <- cr_works(query="renear+-ontologies")
-c <- cr_works(query="global state", filter=c(has_orcid=TRUE), limit=3)
-d <- cr_works(filter=c(has_full_text = TRUE))
-e <- cr_works(dois=c('10.1007/12080.1874-1746','10.1007/10452.1573-5125', '10.1111/(issn)1442-9993'))
-f <- cr_works(query="NSF", facet=TRUE, limit=0)
-g <- cr_works(sample=1)
-h <- cr_works(query="NSF", facet=TRUE)
-i <- suppressWarnings(cr_works(dois=c('blblbl', '10.1038/nnano.2014.279')))
 
-test_that("cr_works returns correct class", {
+test_that("cr_works returns", {
+  skip_on_cran()
+  
+  a <- cr_works(query="NSF")
+  b <- cr_works(query="renear+-ontologies")
+  c <- cr_works(query="global state", filter=c(has_orcid=TRUE), limit=3)
+  d <- cr_works(filter=c(has_full_text = TRUE))
+  e <- cr_works(dois=c('10.1007/12080.1874-1746','10.1007/10452.1573-5125', '10.1111/(issn)1442-9993'))
+  f <- cr_works(query="NSF", facet=TRUE, limit=0)
+  g <- cr_works(sample=1)
+  h <- cr_works(query="NSF", facet=TRUE)
+  i <- suppressWarnings(cr_works(dois=c('blblbl', '10.1038/nnano.2014.279')))
+  
+  # correct class
   expect_is(a, "list")
   expect_is(b, "list")
   expect_is(c, "list")
@@ -36,10 +40,8 @@ test_that("cr_works returns correct class", {
   expect_equal(i$meta, NULL)
   expect_equal(i$facets, NULL)
   expect_is(i$data, "tbl_df")
-  
-})
 
-test_that("cr_works dimensions are correct", {
+  # dimensions are correct
   expect_equal(length(a), 3)
   expect_equal(length(b), 3)
   expect_equal(length(c), 3)
@@ -52,13 +54,17 @@ test_that("cr_works dimensions are correct", {
 })
 
 test_that("cr_works fails correctly", {
+  skip_on_cran()
+  
   library('httr')
   expect_error(cr_works(config=timeout(0.01)))
   expect_equal(NROW(cr_works(query = "adfaaf")$data), 0)
 })
 
+
 test_that("cr_works warns correctly", {
-  expect_warning(cr_works(dois=c('blblbl', '10.1038/nnano.2014.279')), 
-                 regexp = "only data with valid CrossRef dois returned", all = TRUE)
+  skip_on_cran()
+  
+  expect_warning(cr_works(dois=c('blblbl', '10.1038/nnano.2014.279')), "Resource not found")
   expect_equal(NROW(suppressWarnings(cr_works(dois=c('blblbl', '10.1038/nnano.2014.279'))$data)), 1)
 })
